..
    Copyright (C) 2021 Graz University of Technology.

    invenio-imoox is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version v0.3.0 (release 2024-05-29)

- cli: improve success output
- fix: for global search
- cli: give clean message for not existing user
- cli: improve shown error by color
- setup: use ruff
- cli: add dry_run option
- refactor: implement service approach


Version v0.2.0 (release 2022-10-14)

- setup: remove packages coming from pytest-invenio
- change: improve function
- pylint: changes
- global: pin flake8
- fix: install invenio_search[opensearch2] for tests
- fix: sphinx language should not set to None
- global: migrate to reusable workflows
- global: remove explicit install of db and search

